@@ -7,6 +7,7 @@ import time
 from enum import Enum
 from typing import Any, Union, Optional
 import requests
+from custom_python_logger import get_logger
 from jira import JIRA, JIRAError, Issue
 from jira.client import ResultList
 from retrying import retry
@@ -26,17 +27,17 @@ class ServerType(Enum):
 
 class JiraPlus:
     def __init__(
-            self, base_url: Optional[str] = None,
-            server_type: ServerType = ServerType.CLOUD,
-            urllib3_log_level: int = logging.WARNING,
-            jira_username: Optional[str] = None,
-            jira_token: Optional[str] = None,  # Use API token (not PAT)
-            verify_ssl: bool = True,
-            sso: bool = False,
-            url_scheme: UrlScheme = UrlScheme.HTTPS
+        self, base_url: Optional[str] = None,
+        server_type: ServerType = ServerType.CLOUD,
+        urllib3_log_level: int = logging.WARNING,
+        jira_username: Optional[str] = None,
+        jira_token: Optional[str] = None,  # Use API token (not PAT)
+        verify_ssl: bool = True,
+        sso: bool = False,
+        url_scheme: UrlScheme = UrlScheme.HTTPS
     ) -> None:
-        self.logger = logging.getLogger()
-        logging.getLogger("urllib3").setLevel(urllib3_log_level)
+        self.logger = get_logger(self.__class__.__name__)
+        get_logger("urllib3").setLevel(urllib3_log_level)
 
         self.jira_username = jira_username or os.getenv('JIRA_USER_NAME')
         self.jira_token = jira_token or os.getenv('JIRA_TOKEN')
@@ -51,7 +52,7 @@ class JiraPlus:
         self.jira_client = self.create_connection()
         self.check_client_connection()
 
-    @retry(stop_max_attempt_number=3, wait_fixed=180000)  # Retry 3 times with a 3-min (180000) delay between each attempt
+    @retry(stop_max_attempt_number=3, wait_fixed=180000)
     def create_connection(self, timeout=580) -> Optional[JIRA]:
         if self.server_type == ServerType.ON_PREMISE and not self.sso:
             jira_client = JIRA(
@@ -98,10 +99,10 @@ class JiraPlus:
             return False
 
     def get_issue_by_key(
-            self,
-            key: str,
-            specific_fields: str | list[str] = '*all',
-            json_result: bool = True
+        self,
+        key: str,
+        specific_fields: str | list[str] = '*all',
+        json_result: bool = True
     ) -> None | Issue | dict[str, Any]:
         try:
             jira_issue = self.jira_client.issue(id=key, fields=specific_fields)
@@ -116,12 +117,12 @@ class JiraPlus:
             return None
 
     def get_objects_by_query(
-            self,
-            query: str,
-            max_results: int = 5000,
-            specific_fields: Union[str, list[str]] = "*all",
-            jira_err_count: int = 3,
-            json_result: bool = True,
+        self,
+        query: str,
+        max_results: int = 5000,
+        specific_fields: Union[str, list[str]] = "*all",
+        jira_err_count: int = 3,
+        json_result: bool = True,
     ) -> Optional[Union[ResultList[Issue], dict]]:
         return self._paginate_query(
             query=query,
@@ -132,12 +133,12 @@ class JiraPlus:
         )
 
     def _paginate_query(
-            self,
-            query: str,
-            max_results: int,
-            specific_fields: Union[str, list[str]],
-            jira_err_limit: int,
-            json_result: bool
+        self,
+        query: str,
+        max_results: int,
+        specific_fields: Union[str, list[str]],
+        jira_err_limit: int,
+        json_result: bool
     ) -> Union[ResultList[Issue] | list]:
         start_at = 0
         all_issues = []
@@ -161,6 +162,9 @@ class JiraPlus:
                     break
                 retries = 0  # reset on success
             except JIRAError as err:
+                if err.status_code == 400:
+                    self.logger.error(f"Bad Request: {err.text}")
+                    raise JIRAError(f"Bad Request: {err.text}")
                 retries += 1
                 self.logger.warning(f"Retry {retries}/{jira_err_limit} after JIRAError: {err}")
                 if retries >= jira_err_limit:
@@ -189,10 +193,10 @@ class JiraPlus:
         return meta, issue_meta
 
     def get_allowed_values(
-            self,
-            project_key: str,
-            issue_type: str,
-            field_id_or_name: str,
+        self,
+        project_key: str,
+        issue_type: str,
+        field_id_or_name: str,
     ) -> Optional[list]:
         """
         Returns the allowed values for a specific field in a project + issue type context.
@@ -233,9 +237,9 @@ class JiraPlus:
 
     def check_server_createmeta_compatibility(self) -> bool:
         server_version = self.get_server_version()
-        if self.server_type == ServerType.ON_PREMISE and server_version < (8, 0, 0):
+        if self.server_type == ServerType.ON_PREMISE and ''.join(str(x) for x in server_version) > '9.0.0':
             self.logger.warning(
-                f"JIRA server version {server_version} is below the minimum required version (8.0.0). "
+                f"JIRA server version {server_version} is below the minimum required version (9.0.0). "
                 "Some features may not work as expected."
             )
             return False
@@ -252,10 +256,10 @@ class JiraPlus:
             return {f.fieldId: f.raw for f in field_list}
 
     def validate_fields(
-            self,
-            project_key: str,
-            issue_type: str,
-            fields: Optional[dict] = None
+        self,
+        project_key: str,
+        issue_type: str,
+        fields: Optional[dict] = None
     ) -> None:
         fields_metadata = self.get_project_fields_metadata(
             project_key=project_key,
@@ -290,13 +294,13 @@ class JiraPlus:
             # Add more field type checks as needed
 
     def create_issue(
-            self,
-            project_key: str,
-            summary: str,
-            description: str,
-            issue_type: str,
-            assignee: Optional[str] = None,
-            custom_fields: Optional[dict] = None,
+        self,
+        project_key: str,
+        summary: str,
+        description: str,
+        issue_type: str,
+        assignee: Optional[str] = None,
+        custom_fields: Optional[dict] = None,
     ) -> Optional[Issue]:
         issue_fields = {
             "project": {"key": project_key},
@@ -312,21 +316,14 @@ class JiraPlus:
             issue_fields = issue_fields | custom_fields
         self.validate_fields(project_key=project_key, issue_type=issue_type, fields=issue_fields)
 
-        try:
-            issue = self.jira_client.create_issue(fields=issue_fields)
-            self.logger.info(f"Issue {issue.key} created successfully.")
-            return issue
-        except JIRAError as err:
-            self.logger.error(f"JIRAError while creating issue: {err.text}")
-            return None
-        except Exception as err:
-            self.logger.exception(f"Unexpected error: {err}")
-            return None
+        issue = self.jira_client.create_issue(fields=issue_fields)
+        self.logger.info(f"Issue {issue.key} created successfully.")
+        return issue
 
     def update_issue(
-            self,
-            issue_key: str,
-            fields_to_update: dict
+        self,
+        issue_key: str,
+        fields_to_update: dict
     ) -> Optional[Issue]:
         try:
             issue = self.jira_client.issue(issue_key)
@@ -359,6 +356,10 @@ class JiraPlus:
             self.logger.exception(f"Unexpected error: {err}")
             return False
 
+    def add_comment(self, issue: str, comment: str) -> None:
+        self.jira_client.add_comment(issue=issue, body=comment)
+        self.logger.debug(f"Comment added to issue {issue} successfully.")
+
     def _get_available_link_types(self) -> set[str]:
         try:
             return {link_type.name for link_type in self.jira_client.issue_link_types()}
@@ -395,11 +396,11 @@ class JiraPlus:
             self.logger.exception(f"Exception - Attachment {file_path} was not uploaded to issue {issue_key}\n{err}")
 
     def transition_issue(
-            self,
-            issue_key: str,
-            transition_name: str,
-            fields: Optional[dict] = None,
-            comment: Optional[str] = None,
+        self,
+        issue_key: str,
+        transition_name: str,
+        fields: Optional[dict] = None,
+        comment: Optional[str] = None,
     ) -> bool:
         try:
             transitions = self.jira_client.transitions(issue_key)
